@@ -31,7 +31,9 @@ DXClusterWidget::DXClusterWidget(QWidget *parent)
     //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
     awards = new Awards();
     dataProxy = new DataProxy();
+
     initClass();
+    //TESTADDSPOT();
 }
 
 void DXClusterWidget::initClass()
@@ -47,10 +49,18 @@ void DXClusterWidget::initClass()
     showann = true;
     showwwv = true;
     showwcy = true;
-
+    myQrz = QString();
     currentLog = 0;
 }
 
+void DXClusterWidget::setMyQRZ(const QString _qrz)
+{
+    if (_qrz.length()>2)
+    {
+        myQrz = _qrz;
+    }
+
+}
 DXClusterWidget::DXClusterWidget(const QString &clusterToConnect, const int portToConnect, QWidget *parent)
           : QWidget(parent)
 {
@@ -110,6 +120,8 @@ DXClusterWidget::DXClusterWidget(const QString &clusterToConnect, const int port
     // TO BE DELETED
     addData();
 
+     //TESTADDSPOT();
+
 }
 void DXClusterWidget::addData()
 {
@@ -126,7 +138,7 @@ DXClusterWidget::~DXClusterWidget()
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item )
 {
-   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: "  << endl;
+   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
 
     QStringList ql;
     ql.clear();
@@ -134,17 +146,21 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetIt
     if (item)
     {
         ql = readItem(item);
+        //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
         if (ql.length()==2)
         {
             ql << "double";
+            //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
             emit dxspotclicked(ql);
         }
         else
         {
+            //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
         }
     }
     else
     {
+        //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
     }
 
 }
@@ -391,6 +407,7 @@ void DXClusterWidget::slotClusterDataArrived()
         QListWidgetItem *item = new QListWidgetItem();
         item->setForeground(QBrush(dxSpotColor));
         item->setText(dxClusterString);
+
 /*
         if (dxEntity>0)
         {
@@ -443,7 +460,17 @@ void DXClusterWidget::slotClusterSocketConnected()
 
     if (( dxClusterConnected ) && (!dxClusterAlreadyConnected) ){
         bool ok;
-        QString callsignText = QInputDialog::getText(this, tr("KLog message"), tr("Enter your callsign to connect to the cluster:"), QLineEdit::Normal, "", &ok);
+        QString callsignText;
+        if (myQrz.length()>2)
+        {
+            callsignText = QInputDialog::getText(this, tr("KLog message"), tr("Enter your callsign to connect to the cluster:"), QLineEdit::Normal, myQrz, &ok);
+        }
+        else
+        {
+            callsignText = QInputDialog::getText(this, tr("KLog message"), tr("Enter your callsign to connect to the cluster:"), QLineEdit::Normal, "", &ok);
+        }
+
+        //QString callsignText = QInputDialog::getText(this, tr("KLog message"), tr("Enter your callsign to connect to the cluster:"), QLineEdit::Normal, "", &ok);
         QString passwordText = QInputDialog::getText(this, tr("KLog message"), tr("Enter your password to connect to the cluster:\n(Just hit enter for no password)"), QLineEdit::Normal, "", &ok);
         QTextStream os(tcpSocket);
         if ( callsignText.length() > 2 && ok ) {
@@ -700,6 +727,17 @@ void DXClusterWidget::setDXClusterServer(const QString &clusterToConnect, const
     //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
 }
 
+/*
+void DXClusterWidget::TESTADDSPOT()
+{
+    //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
+    ; // Just a test spot
+    QListWidgetItem *item = new QListWidgetItem();
+    item->setForeground(QBrush(dxSpotColor));
+    item->setText("DX de SP0TTER 14.000 DX1CALL");
+    dxClusterListWidget->insertItem(0,item);
+}
+*/
 /***************************************************************************
 ** This is an auxiliary class intended to provide color to the DX-Cluster **
 ** spots.                                                                 **
