@@ -54,6 +54,7 @@ class DXClusterWidget : public QWidget
     void setDXClusterServer(const QString &clusterToConnect, const int portToConnect);
     void setCurrentLog(const int _log);
     bool isConnected();
+    void setMyQRZ(const QString _qrz);
     //void sendSpotToCluster(const QString _dx, const QString _freq);
 
 
@@ -78,6 +79,8 @@ signals:
 
 private:
 
+    //void TESTADDSPOT(); // Just a test spot
+
     void initClass();
     void connectToDXCluster();
     QStringList readItem(QListWidgetItem * item);
@@ -105,7 +108,7 @@ private:
 
     bool showhf, showvhf, showwarc, showworked, showconfirmed, showann,  showwwv, showwcy;
     bool dxClusterShowHF, dxClusterShowVHF, dxClusterShowWARC, dxClusterShowWorked, dxClusterShowConfirmed, dxClusterShowAnn, dxClusterShowWWV, dxClusterShowWCY;
-
+    QString myQrz;
     int currentLog;
 
  };
