@@ -19,23 +19,93 @@
 #include <QtSql>
 #include <QTranslator>
 #include <cstdlib>
-#include <QDebug>
+#include <QTextStream>
+
+//#include <QDebug>
+
 
 #include "startwizard.h"
 #include "mainwindow.h"
+#include "utilities.h"
 
 
 int main(int argc, char *argv[])
 {
-    QString version = "0.9.2.5" ;
+    QString version = "0.9.2.6" ;
     QDir d1 = QDir();
+    Utilities util = Utilities();
+    QStringList arguments;
+    QTextStream cout(stdout);
 
     QApplication app(argc, argv);
 
+    QString iconSt;
+    iconSt = ":/img/klog.ico";
+    QIcon KLogIcon(iconSt);
+    QApplication::setWindowIcon(KLogIcon);
+
+
     //QApplication app(argc, argv);
     app.setApplicationName(QString("KLog"));
     app.setApplicationVersion(QString(version));
 
+
+    // Now we check if the user is executing from the command line
+    arguments.clear();
+    arguments << app.arguments();
+    if (arguments.length()>1)
+    {
+        if (arguments.contains("-h"))
+        {
+            cout << "Usage: klog [OPTION]... [FILE]..." << endl;
+            cout << "Options:" << endl;
+            cout << "     -?           Display this help" << endl;
+            cout << "     -h           Display this help" << endl;
+            cout << "     -v           Display program version" << endl;
+            //cout << "     -e <file>    Export Adif file <file>" << endl;
+        }
+        else if (arguments.contains("-?"))
+        {
+            cout << "Usage: klog [OPTION]... [FILE]..." << endl;
+            cout << "Options:" << endl;
+            cout << "     -?           Display this help" << endl;
+            cout << "     -h           Display this help" << endl;
+            cout << "     -v           Display program version" << endl;
+        }
+        /*
+        else if (arguments.contains("-e"))
+        {
+            //qDebug() << "KLog::main: EXPORT ADIF";
+        }
+        else if (arguments.contains("-u"))
+        {
+            //qDebug() << "KLog::main: UPDATE CTY";
+        }
+        */
+        else if (arguments.contains("-v"))
+        {
+            cout << "Version: KLog-" << app.applicationVersion() << endl;
+        }
+        else
+        {
+            cout << "Usage: klog [OPTION]... [FILE]..." << endl;
+            cout << "Options:" << endl;
+            cout << "     -?           Display this help" << endl;
+            cout << "     -h           Display this help" << endl;
+            cout << "     -v           Display program version" << endl;
+        }
+
+        app.quit();
+        return 0;
+
+    }
+
+    //for (int i=0; i<(app.arguments().length()); i++)
+    //{
+    //  //qDebug() << "KLog::main: Arguments: " << arguments.at(i) << endl;
+    //}
+
+
     // Translations begin
         QTranslator qtTranslator;
         qtTranslator.load("qt_" + QLocale::system().name(),
@@ -43,9 +113,9 @@ int main(int argc, char *argv[])
         app.installTranslator(&qtTranslator);
         QTranslator myappTranslator;
 #if defined(Q_OS_WIN)
-        myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()));
+        myappTranslator.load(QCoreApplication::applicationDirPath() + "/translations/klog_" + (QLocale::system().name()).left(2) + ".qm");
        //qDebug() << "KLog WIN " << endl;
-       ////qDebug() << "KLog: " << QLocale::system().name() << endl;
+       //qDebug() << "KLog: " << QLocale::system().name() << endl;
         //qDebug() << "KLog trans: " <<  QLibraryInfo::location(QLibraryInfo::TranslationsPath) << endl;
         //qDebug() << "KLog currentPath: " <<  QDir::currentPath() << endl;
 #elif defined(Q_OS_OSX)
@@ -77,11 +147,23 @@ int main(int argc, char *argv[])
         else
         {
             QMessageBox msgBox;
+            QString urlTranslate = QString();
+            urlTranslate = "<p><a href=\"https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.\">TRANSLATE</a></p>";
             QString msg = QString();
-            msg = QString(QObject::tr("No translation files for your language have been found so KLog will be shown in English.\n\n")) +
+            msg = QString(QObject::tr("No translation files for your language have been found so KLog will be shown in English.\n\n")) + "<p>" +
                    QString(QObject::tr("If you have the klog_")) + (QLocale::system().name()).left(2) + QString(QObject::tr(".qm file for your language, you can copy it in the "));
+            msgBox.setWindowTitle("KLog");
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.setTextFormat(Qt::RichText);
+// The following URL links to google translator
+//URL: https://translate.google.com/?sl=auto&tl=auto#en/auto/No%20translation%20files%20for%20your%20language%20have%20been%20found%20so%20KLog%20will%20be%20shown%20in%20English.%0A%0AIf%20you%20have%20the%20klog_en.qm%20file%20for%20your%20language%2C%20you%20can%20copy%20it%20in%20the%20%2Fhome%2Fdevel%2F.klog%2F%20folder%20and%20restart%20KLog%20again.%0A%0A%20If%20you%20want%20to%20help%20to%20translate%20KLog%20into%20your%20language%2C%20please%20contact%20the%20author.
+
+            QString msg2;
+            msg2 = QString();
+            msg2 = QObject::tr("folder and restart KLog again.") + "</p><p>" + QObject::tr("If you want to help to translate KLog into your language, please contact the author.</p>") + urlTranslate;
+
+            #ifdef Q_OS_WIN
 
-         #ifdef Q_OS_WIN
             if (QFile::exists(QDir::homePath()+"/klog/klog_" + (QLocale::system().name()).left(2)+ ".qm") )
             {
 
@@ -91,8 +173,8 @@ int main(int argc, char *argv[])
             else
             {
 
-                msg = msg + QDir::homePath()+ QObject::tr("/klog/ folder and restart KLog again.\n\n If you want to help to translate KLog into your language, please contact the author.");
-                msgBox.setText(msg);
+                msg = msg + QDir::homePath()+ "/klog/" + msg2;
+                msgBox.setText(msg);                
                 msgBox.setInformativeText("Do you want to remove the KLog dir from your disk?");
                 msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No );
                 msgBox.setDefaultButton(QMessageBox::Yes);
@@ -111,7 +193,8 @@ int main(int argc, char *argv[])
             }
             else
             {
-                msg = msg + QDir::homePath()+"/.klog/ " + QObject::tr("folder and restart KLog again.\n\n If you want to help to translate KLog into your language, please contact the author.");
+                //msg = msg + QDir::homePath()+"/.klog/ " + QObject::tr("folder and restart KLog again.\n\n If you want to help to translate KLog into your language, please contact the author.")  + urlTranslate;
+                msg = msg + QDir::homePath()+"/.klog/ " + msg2;
                 msgBox.setText(msg);
                 msgBox.setStandardButtons(QMessageBox::Ok);
                 msgBox.setDefaultButton(QMessageBox::Ok);
@@ -123,10 +206,7 @@ int main(int argc, char *argv[])
         }
 #endif
 
-
-
-
-
+    //qDebug() << "KLog Main-1" << endl;
 
     //myappTranslator.load("klog_" + (QLocale::system().name()).left(2));
     //qDebug() << "KLog locale: " << QLocale::system().name() << endl;
@@ -137,29 +217,34 @@ int main(int argc, char *argv[])
     app.installTranslator(&myappTranslator);
 // Translations end
 
-    QString configFileName, kontestDir;
+    QString configFileName, klogDir;
     int inMemory;
     //bool dbInMemory = true;
 
-#ifdef Q_OS_WIN
-    //qDebug() << "WINDOWS DETECTED!"  << endl;
-    kontestDir = QDir::homePath()+"/klog";  // We create the \klog for the logs and data
-    configFileName = kontestDir+"/klogrc.cfg";
-#else
-    //qDebug() << "NO WINDOWS DETECTED!"  << endl;
-    kontestDir = QDir::homePath()+"/.klog";  // We create the ~/.kontest for the logs and data
-    configFileName = kontestDir+"/klogrc";
-#endif
+    klogDir = util.getHomeDir();
+    configFileName = util.getCfgFile();
 
-    //if (!QDir::setCurrent (kontestDir) )
-    if (!QDir::setCurrent (kontestDir) )
+//#ifdef Q_OS_WIN
+    //qDebug() << "WINDOWS DETECTED!"  << endl;
+    //klogDir = QDir::homePath()+"/klog";  // We create the \klog for the logs and data
+//    configFileName = klogDir+"/klogrc.cfg";
+//#else
+    //qDebug() << "NO WINDOWS DETECTED!"  << endl;
+    //klogDir = QDir::homePath()+"/.klog";  // We create the ~/.kontest for the logs and data
+//    configFileName = klogDir+"/klogrc";
+//#endif
+
+   //qDebug() << "KLog Main-10" << endl;
+
+    //if (!QDir::setCurrent (klogDir) )
+    if (!QDir::setCurrent (klogDir) )
     {
         //qDebug() << "MAIN:  KLogDir does not exist.... creating " << endl;
-        //QDir d1(kontestDir);
+        //QDir d1(klogDir);
         //d1.setCurrent()
-        if (d1.mkdir(kontestDir))
+        if (d1.mkdir(klogDir))
         {
-            if (QDir::setCurrent (kontestDir) )
+            if (QDir::setCurrent (klogDir) )
             {
                 //qDebug() << "MAIN:  KLogDir has just been created and pointed " << endl;
             }
@@ -184,21 +269,21 @@ int main(int argc, char *argv[])
     {
         //qDebug() << "MAIN:  Starting wizard... " << endl;
 
-        StartWizard *wizard = new StartWizard(kontestDir, version);        
+        StartWizard *wizard = new StartWizard(klogDir, version);
         wizard->setModal(true);
         inMemory = wizard->exec();
 
         if (inMemory == 1)
         {
           //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in Memory " << endl;
-            MainWindow mw(kontestDir, version);
+            MainWindow mw(klogDir, version);
             mw.show();
             return app.exec();
         }
         else if (inMemory == 2)
         {
            //qDebug() << "MAIN: Wizard accepted " << QString::number(inMemory) << " ... Will run in file " << endl;
-            MainWindow mw(kontestDir, version);
+            MainWindow mw(klogDir, version);
             mw.show();
             return app.exec();
         }
@@ -218,7 +303,7 @@ int main(int argc, char *argv[])
               case QMessageBox::Yes:
                 if (QDir::setCurrent (QDir::homePath()) )
                 {
-                    if (d1.remove(kontestDir))
+                    if (d1.remove(klogDir))
                     {
                         QMessageBox msgBox;
                         msgBox.setText(QObject::tr("Your KLog dir has been removed\n\nThank you for running KLog!"));
@@ -249,12 +334,18 @@ int main(int argc, char *argv[])
     }
     else
     {
-        MainWindow mw(kontestDir, version);
+       //qDebug() << "KLog Main-100" << endl;
+        MainWindow mw(klogDir, version);
+       //qDebug() << "KLog Main-101" << endl;
         mw.show();
+       //qDebug() << "KLog Main-102" << endl;
 
         return app.exec();
+       //qDebug() << "KLog Main-103" << endl;
     }
-
+    //qDebug() << "KLog Main-END" << endl;
     //return app.exec();
 }
 
+
+
