@@ -25,7 +25,7 @@
  *****************************************************************************/
 
 #include "setupdialog.h"
-#include <QDebug>
+//#include <QDebug>
 
 /*
 This class calls all the othet "Setup..." to manage the configuration
@@ -34,13 +34,13 @@ This class calls all the othet "Setup..." to manage the configuration
 
 SetupDialog::SetupDialog(const bool _firstTime)
 {
-   //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+  //qDebug() << "SetupDialog::SetupDialog 1" << endl;
     util = new Utilities;
     nolog = true;
     configFileName = "klogrc";
     version = ".";
     pageRequested = 0;
-   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+  //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     dataProxy = new DataProxy_SQLite();
    //qDebug() << "SetupDialog::SetupDialog 3" << endl;
 
@@ -96,7 +96,7 @@ SetupDialog::SetupDialog(const bool _firstTime)
 
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));       
-    connect (logsPage, SIGNAL(newLogData(QStringList)), this, SLOT(slotAnalyzeNewLogData(QStringList)));
+    connectActions();
 
 
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
@@ -126,10 +126,9 @@ SetupDialog::SetupDialog(const bool _firstTime)
 }
 
 
-
 SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+  //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     util = new Utilities;
     firstTime = _firstTime;
     dataProxy = new DataProxy_SQLite();
@@ -137,6 +136,7 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
     version = _softwareVersion;
     pageRequested = _page;
     int logsPageTabN=-1;
+    //qDebug() << "SetupDialog::SetupDialog 01" << endl;
 
     locator = new Locator();
 
@@ -150,7 +150,7 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
     worldEditorPage = new SetupPageWorldEditor (this);
     logsPage = new SetupPageLogs(this);
     clubLogPage = new SetupPageClubLog(this);
-
+    //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     tabWidget->addTab(userDataPage, tr("User data"));
     tabWidget->addTab(bandsModesPage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
@@ -160,11 +160,12 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
     tabWidget->addTab(clubLogPage, tr("ClubLog"));
 
+    //qDebug() << "SetupDialog::SetupDialog 03" << endl;
+
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
     QPushButton *okButton = new QPushButton(tr("OK"));
 
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
-    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
+
 
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
     horizontalLayout->addWidget(tabWidget);
@@ -178,25 +179,45 @@ SetupDialog::SetupDialog(const QString _configFile, const QString _softwareVersi
     mainLayout->addLayout(horizontalLayout);
     mainLayout->addLayout(buttonsLayout);
 
+    //qDebug() << "SetupDialog::SetupDialog 04" << endl;
+
     setLayout(mainLayout);
 
     setWindowTitle(tr("Config Dialog"));
 
+    //qDebug() << "SetupDialog::SetupDialog 05" << endl;
+
     slotReadConfigData();
+    //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
+       //qDebug() << "SetupDialog::SetupDialog 05.2" << endl;
         tabWidget->setCurrentIndex(logsPageTabN);
     }
+   //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
     nolog = !(haveAtleastOneLog());
-    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+   //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+    connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
+    connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
+    connectActions();
 }
 
+
 SetupDialog::~SetupDialog()
 {
     //qDebug() << "SetupDialog::~SetupDialog " << endl;
 }
 
+void SetupDialog::connectActions()
+{
+
+    connect (logsPage, SIGNAL(newLogData(QStringList)), this, SLOT(slotAnalyzeNewLogData(QStringList)));
+    connect (userDataPage, SIGNAL(stationCallSignal(QString)), this, SLOT(slotSetStationCallSign(QString)));
+    connect (userDataPage, SIGNAL(operatorsSignal(QString)), this, SLOT(slotSetOperators(QString)));
+
+}
+
 void SetupDialog::setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
   //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
@@ -333,6 +354,7 @@ void SetupDialog::slotOkButtonClicked()
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
         msgBox.setText(tr("You need to enter at least a valid QRZ."));
+        msgBox.setInformativeText(tr("Go to the") + " " + tr("User tab") + " " + tr("and enter valid QRZ."));
         msgBox.exec();
         return;
     }
@@ -343,7 +365,8 @@ void SetupDialog::slotOkButtonClicked()
 
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
-        msgBox.setText(tr("You have not selected the kind of log you want.\nYou will be redirected to the Log tab.\nPlease add and select the kind of log you want to use."));
+        msgBox.setText(tr("You have not selected the kind of log you want."));
+        msgBox.setInformativeText(tr("You will be redirected to the Log tab.\nPlease add and select the kind of log you want to use."));
         msgBox.exec();
 
         tabWidget->setCurrentIndex(tabWidget->indexOf(logsPage));
@@ -464,6 +487,12 @@ void SetupDialog::slotOkButtonClicked()
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
         stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
+        stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  endl;
+
+        if ((miscPage->getReportInfo()).toUpper() == "TRUE")
+        {
+            stream << "ProvideInfo=True;"  <<  endl;
+        }
 
 
         if ((!(dxClusterPage->getSelectedDxClusterServer()).isNull()) && (  (dxClusterPage->getSelectedDxClusterServer()).length() > 0   ))
@@ -522,7 +551,7 @@ void SetupDialog::slotOkButtonClicked()
 
 void SetupDialog::slotReadConfigData()
 {
-  //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+ //qDebug() << "SetupDialog::slotReadConfigData" << endl;
     if (firstTime)
     {
         setDefaults();
@@ -532,22 +561,25 @@ void SetupDialog::slotReadConfigData()
         bandsModesPage->setActiveBands(bands);
     }
 
+    //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-       //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
+      //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         return;
     }
-
+    //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
     //dxClusterServers.clear();
 
 
 
     while (!file.atEnd()) {
         QByteArray line = file.readLine();
-        processConfigLine(line);
+        processConfigLine(line);        
+       //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
     }
+    //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
 
     dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
@@ -562,19 +594,20 @@ void SetupDialog::slotReadConfigData()
         bands << "10M" << "12M" << "15M" << "17M" << "20M" << "40M" << "80M" << "160M";
 
     }
-    int a = modes.removeDuplicates();
+    modes.removeDuplicates();
     //qDebug() << "SetupDialog::slotReadConfigData - duplicate modes: " << QString::number(a)  << endl;
     bandsModesPage->setActiveModes(modes);
-    a = bands.removeDuplicates();
-   //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
+    bands.removeDuplicates();
+  //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
     bandsModesPage->setActiveBands(bands);
+   //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
 
 }
 
 bool SetupDialog::processConfigLine(const QString _line)
 {
 
-    //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
+   //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
 
     QString line = _line.simplified();
     //line.simplified();
@@ -646,6 +679,12 @@ bool SetupDialog::processConfigLine(const QString _line)
     else if (tab=="SHOWCALLSIGNINSEARCH"){
         miscPage->setShowStationCallSignInSearch(value.toLower());
     }
+    else if (tab=="CHECKNEWVERSIONS"){
+        miscPage->setCheckNewVersions(value);
+    }
+    else if (tab=="PROVIDEINFO"){
+        miscPage->setReportInfo(value);
+    }
     else if (tab =="NAME")
     {
         userDataPage->setName(value);
@@ -789,7 +828,7 @@ bool SetupDialog::processConfigLine(const QString _line)
 
     // Lines are: Option = value;
 
-
+    //qDebug() << "SetupDialog::processConfigLine: END "  << endl;
     return true;
 
 
@@ -899,6 +938,8 @@ void SetupDialog::setDefaults()
     miscPage->setSendQSLWhenRec("TRUE");
     miscPage->setShowStationCallSignInSearch("TRUE");
     miscPage->setKeepMyData("TRUE");
+    miscPage->setCheckNewVersions("TRUE");
+    miscPage->setReportInfo("FALSE");
 
     dxClusterPage->setShowHFRadiobutton("TRUE");
     dxClusterPage->setShowVHFRadiobutton("TRUE");
@@ -1007,3 +1048,16 @@ void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
     userDataPage->setStationQrz(_qs.at(0));
     userDataPage->setOperators(_qs.at(1));
 }
+
+void SetupDialog::slotSetStationCallSign(const QString _p)
+{
+    //qDebug() << "SetupDialog::slotSetStationCallSign: " << _p << endl;
+    logsPage->setDefaultStationCallsign(_p);
+}
+
+void SetupDialog::slotSetOperators(const QString _p)
+{
+    //qDebug() << "SetupDialog::slotSetOperators: " << _p << endl;
+    logsPage->setDefaultOperators(_p);
+}
+
