@@ -45,6 +45,7 @@ SetupPageLogs::SetupPageLogs(QWidget *parent) : QWidget(parent){
     typeContestN = -1;
 
     selectedLog = -1;
+    defaultStationCallSign.clear();
 
     //setupD = new SetupDialog();
 
@@ -118,6 +119,15 @@ void SetupPageLogs::createNewLog()
     selectedLog = -1;
     //newLog->clear();
     newLog->setEditing(false);
+    if (defaultStationCallSign.length()>2)
+    {
+        newLog->setStationCallSign(defaultStationCallSign);
+    }
+    if (defaultOperators.length()>2)
+    {
+        newLog->setOperators(defaultOperators);
+    }
+
     newLog->exec();
 }
 
@@ -599,3 +609,16 @@ void SetupPageLogs::showError(const QString _errorC)
                                    QMessageBox::Ok);
 
 }
+
+void SetupPageLogs::setDefaultStationCallsign(const QString _p)
+{
+    //qDebug() << "SetupPageLogs::setDefaultStationCallsign: " << _p << endl;
+    defaultStationCallSign = _p;
+}
+
+void SetupPageLogs::setDefaultOperators(const QString _p)
+{
+    //qDebug() << "SetupPageLogs::setDefaultOperators: " << _p << endl;
+    defaultOperators = _p;
+
+}
