@@ -49,6 +49,8 @@ public:
     int getSelectedLog();
     void setSelectedLog(const int _i);
     void createNewLog();
+    void setDefaultStationCallsign (const QString _p);
+    void setDefaultOperators(const QString _p);
 /*
     QString getBands(); // 10m, 12m, 15m
     QString getModes(); //ssb, CW
@@ -128,6 +130,8 @@ private:
     DataProxy *dataProxy;
     int selectedLog;
 
+    QString defaultStationCallSign, defaultOperators;
+
 
 };
 
