@@ -295,6 +295,9 @@ void SetupPageUserDataPage::slotQRZTextChanged()
 
     qrzLineEdit->setCursorPosition(i);
 
+    emit stationCallSignal(qrzLineEdit->text());
+    //emit stationCallSignal("TEST");
+
     /*
      if (!locator->isValidLocator(myLocatorLineEdit->text()) )
     {
@@ -649,6 +652,8 @@ void SetupPageUserDataPage::slotOperatorsChanged()
 
         operatorsLineEdit->setPalette(*defaultPalette);
 
+        emit operatorsSignal(operatorsLineEdit->text());
+
     }
     else
     {
