@@ -8,6 +8,7 @@ SetupPageWorldEditor::SetupPageWorldEditor(QWidget *parent) : QWidget(parent)
     //worldPanel = new QWidget;
 
     world = new World();
+    util = new Utilities();
 
     setupEntityDialog = new SetupEntityDialog();
 
@@ -44,9 +45,9 @@ SetupPageWorldEditor::SetupPageWorldEditor(QWidget *parent) : QWidget(parent)
     editEntityPushButton->setToolTip("Still not implemented.");
 
     exportWorldPushButton->setEnabled(false);
-    loadWorldPushButton->setEnabled(false);
+    loadWorldPushButton->setEnabled(true);
     exportWorldPushButton->setToolTip("Still not implemented.");
-    loadWorldPushButton->setToolTip("Still not implemented.");
+    loadWorldPushButton->setToolTip("Import a new CTY.CSV file");
 
 
     QHBoxLayout *buttonsLayout = new QHBoxLayout;
@@ -75,6 +76,31 @@ SetupPageWorldEditor::SetupPageWorldEditor(QWidget *parent) : QWidget(parent)
 
     createActions();
 
+    if (isWorldEmpty())
+    {
+        QString ctyfile = util->getCTYFile();
+
+        QMessageBox msgBox;
+        if (QFile::exists(ctyfile))
+        {
+
+            msgBox.setIcon(QMessageBox::Information);
+            msgBox.setText(tr("An entities information file (CTY.CSV) has been detected in your KLog folder and will be loaded."));
+            msgBox.exec();
+            world->recreate(ctyfile);
+            worldModel->select();
+            //slotImportWorldButtonClicked();
+        }
+        else
+        {
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.setText(tr("No entities information file (CTY.CSV) has been detected in your KLog folder."));
+            msgBox.setInformativeText(tr("KLog will not be able to show entities information."));
+            msgBox.exec();
+        }
+
+    }
+
 }
 
 SetupPageWorldEditor::~SetupPageWorldEditor()
@@ -191,6 +217,11 @@ void SetupPageWorldEditor::createActions()
     connect(delEntityPushButton, SIGNAL(clicked()), this, SLOT(slotDelButtonClicked()) );
     connect(editEntityPushButton, SIGNAL(clicked()), this, SLOT(slotEditButtonClicked()) );
 
+    connect(loadWorldPushButton, SIGNAL(clicked()), this, SLOT(slotImportWorldButtonClicked()) );
+
+
+
+
     connect(worldView, SIGNAL(doubleClicked ( const QModelIndex& ) ), this, SLOT(slotDoubleClickEntity( const QModelIndex& ) ) );
 
     //SIGNAL received from the setupEntityDialog
@@ -217,6 +248,20 @@ void SetupPageWorldEditor::slotAnalyzeEntityAddedSignal(const QStringList _qs)
                 */
 }
 
+bool SetupPageWorldEditor::isWorldEmpty()
+{
+    // I need to check if the world is empty and I have the CTY.CSV file
+    if (world->getHowManyEntities()<1)
+    {
+        return true;
+    }
+    else
+    {
+       return false;
+    }
+    return true;
+}
+
 void SetupPageWorldEditor::slotAddButtonClicked()
 {
     //qDebug() << "SetupPageWorldEditor::slotAddButtonClicked" << endl;
@@ -248,8 +293,36 @@ void SetupPageWorldEditor::slotDoubleClickEntity( const QModelIndex & index)
 
     //qDebug() << "SetupPageWorldEditor::slotDoubleClickEntity: ARRLid: " << QString::number((worldModel->index(row, 8)).data(0).toInt()) << endl;
 
+}
+
+void SetupPageWorldEditor::slotImportWorldButtonClicked()
+{
+    //qDebug() << "SetupPageWorldEditor::slotImportWorldButtonClicked" << endl;
+    QString klogDir;
+    klogDir = util->getHomeDir();
+    QString worldFile;
+    worldFile.clear();
+    worldFile = QFileDialog::getOpenFileName(this, tr("Open File"), klogDir, tr("BigCTY (*.csv)"));
+
+    QMessageBox msgBox;
+    //qDebug() << "SetupPageWorldEditor::slotImportWorldButtonClicked: " << worldFile << endl;
+
+    if (world->recreate(worldFile) )
+    {
+
+        msgBox.setIcon(QMessageBox::Information);
+        msgBox.setText(tr("Entities information has been updated."));
+        worldModel->select();
+    }
+    else
+    {
+        msgBox.setIcon(QMessageBox::Warning);
+        msgBox.setText(tr("Entities information has not been updated."));
+    }
 
 
+    msgBox.exec();
+    //qDebug() << "SetupPageWorldEditor::slotImportWorldButtonClicked - END" << endl;
 }
 
 
